Author: danielsh
Date: Sun Oct 31 13:39:41 2010
New Revision: 1029339

URL: http://svn.apache.org/viewvc?rev=1029339&view=rev
Log:
On the 'performance' branch, some API docstring housekeeping.

* subversion/include/svn_ra_svn.h
  (svn_ra_svn_create_conn2, svn_ra_svn_create_conn,
   svn_ra_svn_compression_level):
     Add @since/@deprecated marks as needed.

* subversion/include/svn_string.h
  (svn_stringbuf_create_empty):
     Add @since marks as needed.

Modified:
    subversion/branches/performance/subversion/include/svn_ra_svn.h
    subversion/branches/performance/subversion/include/svn_string.h

Modified: subversion/branches/performance/subversion/include/svn_ra_svn.h
URL: 
http://svn.apache.org/viewvc/subversion/branches/performance/subversion/include/svn_ra_svn.h?rev=1029339&r1=1029338&r2=1029339&view=diff
==============================================================================
--- subversion/branches/performance/subversion/include/svn_string.h (original)
+++ subversion/branches/performance/subversion/include/svn_string.h Sun Oct 31 
13:39:41 2010
@@ -197,6 +197,7 @@ svn_stringbuf_t *
 svn_stringbuf_ncreate(const char *bytes, apr_size_t size, apr_pool_t *pool);
 
 /** Create a truely empty string object (length and blocksize are 0)
+ * @since New in 1.7.
  */
 svn_stringbuf_t *
 svn_stringbuf_create_empty(apr_pool_t *pool);


Reply via email to
--- subversion/branches/performance/subversion/include/svn_ra_svn.h (original)
+++ subversion/branches/performance/subversion/include/svn_ra_svn.h Sun Oct 31 
13:39:41 2010
@@ -163,6 +163,8 @@ typedef svn_error_t *(*svn_ra_svn_edit_c
  * Either @a sock or @a in_file/@a out_file must be set, not both.
  * Specify the desired network data compression level (zlib) from
  * 0 (no compression) to 9 (best but slowest).
+ *
+ * @since New in 1.7.
  */
 svn_ra_svn_conn_t *
 svn_ra_svn_create_conn2(apr_socket_t *sock,
@@ -171,9 +173,12 @@ svn_ra_svn_create_conn2(apr_socket_t *so
                         int compression_level,
                         apr_pool_t *pool);
 
 /** Similar to @ref svn_ra_svn_create_conn2 but uses default 
  * compression for network transmissions.
  */
+SVN_DEPRECATED
 svn_ra_svn_conn_t *
 svn_ra_svn_create_conn(apr_socket_t *sock,
                        apr_file_t *in_file,
@@ -197,7 +202,10 @@ svn_boolean_t
 svn_ra_svn_has_capability(svn_ra_svn_conn_t *conn,
                           const char *capability);
 
-/** Return the data compression level to use for network transmissions */
+/** Return the data compression level to use for network transmissions
+ * 
+ * @since New in 1.7.
+ */
 int
 svn_ra_svn_compression_level(svn_ra_svn_conn_t *conn);
 
@@ -171,9 +173,12 @@ svn_ra_svn_create_conn2(apr_socket_t *so
                         apr_pool_t *pool);
 
-/** Similar to @ref svn_ra_svn_create_conn2 but uses default 
- * compression for network transmissions.
+/** Similar to @ref svn_ra_svn_create_conn2() but uses default 
+ * compression level (#SVNDIFF1_COMPRESS_LEVEL) for network transmissions.
+ * 
+ * @deprecated Provided for backward compatibility with the 1.6 API.
  */

Modified: subversion/branches/performance/subversion/include/svn_string.h
URL: 
http://svn.apache.org/viewvc/subversion/branches/performance/subversion/include/svn_string.h?rev=1029339&r1=1029338&r2=1029339&view=diff
==============================================================================